@@ -1,32 +1,16 @@
-/****************************************************************************
-**
-** Copyright (C) 2007 - 2010 Urs Wolfer <uwolfer @ kde.org>
-**
-** This file is part of KDE.
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; see the file COPYING. If not, write to
-** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-** Boston, MA 02110-1301, USA.
-**
-****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007-2010 Urs Wolfer <uwolfer@kde.org>
+    SPDX-FileCopyrightText: 2021 Rafał Lalik <rafallalik@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "hostpreferences.h"
 #include "krdc_debug.h"
 #include "settings.h"
 
 #include <KLocalizedString>
-#include <KWidgetsAddons/KPageDialog>
+#include <KPageDialog>
 
 #include <QCheckBox>
 #include <QDialog>
@@ -127,6 +111,16 @@ void HostPreferences::setWindowedScale(bool scale)
     m_configGroup.writeEntry("windowedScale", scale);
 }
 
+int HostPreferences::scaleFactor()
+{
+    return m_configGroup.readEntry("scaleFactor", 0);
+}
+
+void HostPreferences::setScaleFactor(int factor)
+{
+    m_configGroup.writeEntry("scaleFactor", factor);
+}
+
 bool HostPreferences::grabAllKeys()
 {
     return m_configGroup.readEntry("grabAllKeys", false);
