@@ -21,6 +21,7 @@
 #include <freerdp/input.h>
 #include <freerdp/client.h>
 #include <freerdp/client/channels.h>
+#include <freerdp/client/cliprdr.h>
 #include <freerdp/client/cmdline.h>
 #include <freerdp/client/rdpgfx.h>
 #include <freerdp/channels/rdpgfx.h>
@@ -167,15 +168,21 @@ void channelConnected(void* context, ChannelConnectedEventArgs* e)
     auto rdpC = reinterpret_cast<rdpContext*>(context);
     if (strcmp(e->name, RDPGFX_DVC_CHANNEL_NAME) == 0) {
 		gdi_graphics_pipeline_init(rdpC->gdi, (RdpgfxClientContext*)e->pInterface);
-	}
+    } else if (strcmp(e->name, CLIPRDR_SVC_CHANNEL_NAME) == 0) {
+        CliprdrClientContext* clip = (CliprdrClientContext*)e->pInterface;
+        clip->custom = context;
+    }
 }
 
 void channelDisconnected(void* context, ChannelDisconnectedEventArgs* e)
 {
     auto rdpC = reinterpret_cast<rdpContext*>(context);
     if (strcmp(e->name, RDPGFX_DVC_CHANNEL_NAME) == 0) {
-		gdi_graphics_pipeline_uninit(rdpC->gdi, (RdpgfxClientContext*)e->pInterface);
-	}
+        gdi_graphics_pipeline_uninit(rdpC->gdi, (RdpgfxClientContext*)e->pInterface);
+    } else if (strcmp(e->name, CLIPRDR_SVC_CHANNEL_NAME) == 0) {
+        CliprdrClientContext* clip = (CliprdrClientContext*)e->pInterface;
+        clip->custom = nullptr;
+    }
 }
 
 QString Certificate::toString() const
@@ -265,6 +272,11 @@ QSize RdpSession::size() const
     return m_size;
 }
 
+void RdpSession::setSize(QSize size)
+{
+    m_size = size;
+}
+
 bool RdpSession::start()
 {
     setState(State::Starting);
@@ -302,9 +314,9 @@ bool RdpSession::start()
     settings->Username = qstrdup(m_user.toLocal8Bit().data());
     settings->Password = qstrdup(m_password.toLocal8Bit().data());
 
-    if (m_preferences->width() > 0 && m_preferences->height() > 0) {
-        settings->DesktopWidth = m_preferences->width();
-        settings->DesktopHeight = m_preferences->height();
+    if (m_size.width() > 0 && m_size.height() > 0) {
+        settings->DesktopWidth = m_size.width();
+        settings->DesktopHeight = m_size.height();
     }
 
     switch (m_preferences->acceleration()) {
@@ -430,6 +442,7 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
     }
     case QEvent::MouseButtonPress:
     case QEvent::MouseButtonRelease:
+    case QEvent::MouseButtonDblClick:
     case QEvent::MouseMove: {
         auto mouseEvent = static_cast<QMouseEvent *>(event);
         auto position = mouseEvent->localPos();
@@ -454,14 +467,16 @@ bool RdpSession::sendEvent(QEvent *event, QWidget *source)
         case Qt::BackButton:
             flags |= PTR_XFLAGS_BUTTON1;
             extendedEvent = true;
+            break;
         case Qt::ForwardButton:
             flags |= PTR_XFLAGS_BUTTON2;
             extendedEvent = true;
+            break;
         default:
             break;
         }
 
-        if (mouseEvent->type() == QEvent::MouseButtonPress) {
+        if (mouseEvent->type() == QEvent::MouseButtonPress || mouseEvent->type() == QEvent::MouseButtonDblClick) {
             if (extendedEvent) {
                 flags |= PTR_XFLAGS_DOWN;
             } else {
